==> ZenTaoPMS.max2.2.php7.2_7.4.zip: zentaopms/module/common/lang/common.php <==
<?php
$lang->common      = new stdclass();
$lang->index       = new stdclass();
$lang->my          = new stdclass();
$lang->todo        = new stdclass();
$lang->program     = new stdclass();
$lang->product     = new stdclass();
$lang->project     = new stdclass();
$lang->scrum       = new stdclass();
$lang->waterfall   = new stdclass();
$lang->execution   = new stdclass();
$lang->story       = new stdclass();
$lang->release     = new stdclass();
$lang->branch      = new stdclass();
$lang->productplan = new stdclass();
$lang->measurement = new stdclass();
$lang->review      = new stdclass();
$lang->milestone   = new stdclass();
$lang->qa          = new stdclass();
$lang->doc         = new stdclass();
$lang->system      = new stdclass();
$lang->testcase    = new stdclass();
$lang->testtask    = new stdclass();
$lang->testreport  = new stdclass();
$lang->score       = new stdclass();
$lang->auditplan   = new stdclass();
$lang->cm          = new stdclass();
$lang->nc          = new stdclass();
$lang->pssp        = new stdclass();
$lang->stakeholder = new stdclass();
$lang->task        = new stdclass();
$lang->build       = new stdclass();
$lang->bug         = new stdclass();
$lang->company     = new stdclass();
$lang->dept        = new stdclass();
$lang->group       = new stdclass();
$lang->user        = new stdclass();
$lang->report      = new stdclass();
$lang->repo        = new stdclass();
$lang->jenkins     = new stdclass();
$lang->gitlab      = new stdclass();
$lang->mr          = new stdclass();
$lang->compile     = new stdclass();
$lang->job         = new stdclass();
$lang->svn         = new stdclass();
$lang->git         = new stdclass();
$lang->subject     = new stdclass();
$lang->company     = new stdclass();
$lang->admin       = new stdclass();
$lang->convert     = new stdclass();
$lang->upgrade     = new stdclass();
$lang->action      = new stdclass();
$lang->backup      = new stdclass();
$lang->extension   = new stdclass();
$lang->custom      = new stdclass();
$lang->mail        = new stdclass();
$lang->cron        = new stdclass();
$lang->dev         = new stdclass();
$lang->entry       = new stdclass();
$lang->webhook     = new stdclass();
$lang->message     = new stdclass();
$lang->search      = new stdclass();
$lang->devops      = new stdclass();
$lang->team        = new stdclass();
$lang->automation  = new stdclass();
$lang->personnel   = new stdclass();
$lang->mail        = new stdclass();
$lang->testsuite   = new stdclass();
$lang->caselib     = new stdclass();
$lang->ci          = new stdclass();
$lang->datatable   = new stdclass();
$lang->tree        = new stdclass();
$lang->api         = new stdclass();
$lang->file        = new stdclass();
$lang->misc        = new stdclass();

$lang->projectbuild   = new stdclass();
$lang->projectrelease = new stdclass();
$lang->projectstory   = new stdclass();

/* Common action icons. */
$lang->icons['todo']      = 'check';
$lang->icons['product']   = 'product';
$lang->icons['bug']       = 'bug';
$lang->icons['task']      = 'check-sign';
$lang->icons['tasks']     = 'tasks';
$lang->icons['program']   = 'program';
$lang->icons['project']   = 'project';
$lang->icons['stage']     = 'waterfall';
$lang->icons['sprint']    = 'sprint';
$lang->icons['doc']       = 'file-text';
$lang->icons['doclib']    = 'folder-close';
$lang->icons['story']     = 'lightbulb';
$lang->icons['release']   = 'tags';
$lang->icons['roadmap']   = 'code-fork';
$lang->icons['plan']      = 'flag';
$lang->icons['dynamic']   = 'volume-up';
$lang->icons['build']     = 'tag';
$lang->icons['test']      = 'check';
$lang->icons['testtask']  = 'check';
$lang->icons['group']     = 'group';
$lang->icons['team']      = 'group';
$lang->icons['company']   = 'sitemap';
$lang->icons['user']      = 'user';
$lang->icons['dept']      = 'sitemap';
$lang->icons['tree']      = 'sitemap';
$lang->icons['usecase']   = 'sitemap';
$lang->icons['testcase']  = 'sitemap';
$lang->icons['result']    = 'list-alt';
$lang->icons['mail']      = 'envelope';
$lang->icons['trash']     = 'trash';
$lang->icons['extension'] = 'th-large';
$lang->icons['app']       = 'th-large';

$lang->icons['results']            = 'list-alt';
$lang->icons['create']             = 'plus';
$lang->icons['post']               = 'edit';
$lang->icons['batchCreate']        = 'plus-sign';
$lang->icons['batchEdit']          = 'edit-sign';
$lang->icons['batchClose']         = 'off';
$lang->icons['edit']               = 'edit';
$lang->icons['delete']             = 'close';
$lang->icons['copy']               = 'copy';
$lang->icons['report']             = 'bar-chart';
$lang->icons['export']             = 'export';
$lang->icons['report-file']        = 'file-powerpoint';
$lang->icons['import']             = 'import';
$lang->icons['finish']             = 'checked';
$lang->icons['resolve']            = 'check';
$lang->icons['start']              = 'play';
$lang->icons['restart']            = 'play';
$lang->icons['run']                = 'run';
$lang->icons['runCase']            = 'run';
$lang->icons['batchRun']           = 'play-sign';
$lang->icons['assign']             = 'hand-right';
$lang->icons['assignTo']           = 'hand-right';
$lang->icons['change']             = 'fork';
$lang->icons['link']               = 'link';
$lang->icons['close']              = 'off';
$lang->icons['activate']           = 'magic';
$lang->icons['review']             = 'glasses';
$lang->icons['confirm']            = 'search';
$lang->icons['confirmBug']         = 'search';
$lang->icons['putoff']             = 'calendar';
$lang->icons['suspend']            = 'pause';
$lang->icons['pause']              = 'pause';
$lang->icons['cancel']             = 'ban-circle';
$lang->icons['recordEstimate']     = 'time';
$lang->icons['customFields']       = 'cogs';
$lang->icons['manage']             = 'cog';
$lang->icons['unlock']             = 'unlock-alt';
$lang->icons['confirmStoryChange'] = 'search';
$lang->icons['score']              = 'tint';

$lang->createIcons['todo']      = 'todo';
$lang->createIcons['effort']    = 'time';
$lang->createIcons['bug']       = 'bug';
$lang->createIcons['story']     = 'lightbulb';
$lang->createIcons['task']      = 'check-sign';
$lang->createIcons['testcase']  = 'sitemap';
$lang->createIcons['doc']       = 'doc';
$lang->createIcons['execution'] = 'run';
$lang->createIcons['project']   = 'project';
$lang->createIcons['product']   = 'product';
$lang->createIcons['program']   = 'program';

$lang->noMenuModule = array('report', 'my', 'todo', 'effort', 'program', 'product', 'execution', 'task', 'build', 'productplan', 'project', 'projectrelease', 'projectstory', 'story', 'branch', 'release', 'attend', 'leave', 'makeup', 'overtime', 'lieu', 'custom', 'admin', 'mail', 'extension', 'dev', 'backup', 'action', 'cron', 'pssp', 'sms', 'message', 'webhook', 'search', 'score', 'stage', 'entry', 'jenkins', 'gitlab');

if(isset($_SESSION['tutorialMode']) and $_SESSION['tutorialMode'] and !defined('TUTORIAL')) define('TUTORIAL', true);

==> ZenTaoPMS.max2.4.php7.0.zip: zentaopms/module/common/lang/common.php <==
<?php
$lang->common      = new stdclass();
$lang->index       = new stdclass();
$lang->my          = new stdclass();
$lang->todo        = new stdclass();
$lang->program     = new stdclass();
$lang->programplan = new stdclass();
$lang->product     = new stdclass();
$lang->project     = new stdclass();
$lang->design      = new stdclass();
$lang->stage       = new stdclass();
$lang->scrum       = new stdclass();
$lang->waterfall   = new stdclass();
$lang->execution   = new stdclass();
$lang->kanban      = new stdclass();
$lang->story       = new stdclass();
$lang->release     = new stdclass();
$lang->branch      = new stdclass();
$lang->productplan = new stdclass();
$lang->measurement = new stdclass();
$lang->review      = new stdclass();
$lang->milestone   = new stdclass();
$lang->qa          = new stdclass();
$lang->doc         = new stdclass();
$lang->system      = new stdclass();
$lang->testcase    = new stdclass();
$lang->testtask    = new stdclass();
$lang->testreport  = new stdclass();
$lang->score       = new stdclass();
$lang->auditplan   = new stdclass();
$lang->cm          = new stdclass();
$lang->nc          = new stdclass();
$lang->pssp        = new stdclass();
$lang->stakeholder = new stdclass();
$lang->task        = new stdclass();
$lang->build       = new stdclass();
$lang->bug         = new stdclass();
$lang->company     = new stdclass();
$lang->dept        = new stdclass();
$lang->group       = new stdclass();
$lang->user        = new stdclass();
$lang->report      = new stdclass();
$lang->repo        = new stdclass();
$lang->jenkins     = new stdclass();
$lang->gitlab      = new stdclass();
$lang->mr          = new stdclass();
$lang->compile     = new stdclass();
$lang->job         = new stdclass();
$lang->svn         = new stdclass();
$lang->git         = new stdclass();
$lang->subject     = new stdclass();
$lang->company     = new stdclass();
$lang->admin       = new stdclass();
$lang->convert     = new stdclass();
$lang->upgrade     = new stdclass();
$lang->action      = new stdclass();
$lang->backup      = new stdclass();
$lang->extension   = new stdclass();
$lang->custom      = new stdclass();
$lang->mail        = new stdclass();
$lang->cron        = new stdclass();
$lang->dev         = new stdclass();
$lang->entry       = new stdclass();
$lang->webhook     = new stdclass();
$lang->message     = new stdclass();
$lang->search      = new stdclass();
$lang->devops      = new stdclass();
$lang->team        = new stdclass();
$lang->automation  = new stdclass();
$lang->personnel   = new stdclass();
$lang->mail        = new stdclass();
$lang->testsuite   = new stdclass();
$lang->caselib     = new stdclass();
$lang->ci          = new stdclass();
$lang->datatable   = new stdclass();
$lang->tree        = new stdclass();
$lang->api         = new stdclass();
$lang->file        = new stdclass();
$lang->misc        = new stdclass();
$lang->acl         = new stdclass();
$lang->curd        = new stdclass();

$lang->projectbuild   = new stdclass();
$lang->projectrelease = new stdclass();
$lang->projectstory   = new stdclass();

/* Common action icons. */
$lang->icons['todo']      = 'check';
$lang->icons['product']   = 'product';
$lang->icons['bug']       = 'bug';
$lang->icons['task']      = 'check-sign';
$lang->icons['tasks']     = 'tasks';
$lang->icons['program']   = 'program';
$lang->icons['project']   = 'project';
$lang->icons['stage']     = 'waterfall';
$lang->icons['sprint']    = 'sprint';
$lang->icons['doc']       = 'file-text';
$lang->icons['doclib']    = 'folder-close';
$lang->icons['story']     = 'lightbulb';
$lang->icons['release']   = 'tags';
$lang->icons['roadmap']   = 'code-fork';
$lang->icons['plan']      = 'flag';
$lang->icons['dynamic']   = 'volume-up';
$lang->icons['build']     = 'tag';
$lang->icons['test']      = 'check';
$lang->icons['testtask']  = 'check';
$lang->icons['group']     = 'group';
$lang->icons['team']      = 'group';
$lang->icons['company']   = 'sitemap';
$lang->icons['user']      = 'user';
$lang->icons['dept']      = 'sitemap';
$lang->icons['tree']      = 'sitemap';
$lang->icons['usecase']   = 'sitemap';
$lang->icons['testcase']  = 'sitemap';
$lang->icons['result']    = 'list-alt';
$lang->icons['mail']      = 'envelope';
$lang->icons['trash']     = 'trash';
$lang->icons['extension'] = 'th-large';
$lang->icons['app']       = 'th-large';

$lang->icons['results']            = 'list-alt';
$lang->icons['create']             = 'plus';
$lang->icons['post']               = 'edit';
$lang->icons['batchCreate']        = 'plus-sign';
$lang->icons['batchEdit']          = 'edit-sign';
$lang->icons['batchClose']         = 'off';
$lang->icons['edit']               = 'edit';
$lang->icons['delete']             = 'close';
$lang->icons['copy']               = 'copy';
$lang->icons['report']             = 'bar-chart';
$lang->icons['export']             = 'export';
$lang->icons['report-file']        = 'file-powerpoint';
$lang->icons['import']             = 'import';
$lang->icons['finish']             = 'checked';
$lang->icons['resolve']            = 'check';
$lang->icons['start']              = 'play';
$lang->icons['restart']            = 'play';
$lang->icons['run']                = 'run';
$lang->icons['runCase']            = 'run';
$lang->icons['batchRun']           = 'play-sign';
$lang->icons['assign']             = 'hand-right';
$lang->icons['assignTo']           = 'hand-right';
$lang->icons['change']             = 'fork';
$lang->icons['link']               = 'link';
$lang->icons['close']              = 'off';
$lang->icons['activate']           = 'magic';
$lang->icons['review']             = 'glasses';
$lang->icons['confirm']            = 'search';
$lang->icons['confirmBug']         = 'search';
$lang->icons['putoff']             = 'calendar';
$lang->icons['suspend']            = 'pause';
$lang->icons['pause']              = 'pause';
$lang->icons['cancel']             = 'ban-circle';
$lang->icons['recordEstimate']     = 'time';
$lang->icons['customFields']       = 'cogs';
$lang->icons['manage']             = 'cog';
$lang->icons['unlock']             = 'unlock-alt';
$lang->icons['confirmStoryChange'] = 'search';
$lang->icons['score']              = 'tint';

$lang->createIcons['todo']        = 'todo';
$lang->createIcons['effort']      = 'time';
$lang->createIcons['bug']         = 'bug';
$lang->createIcons['story']       = 'lightbulb';
$lang->createIcons['task']        = 'check-sign';
$lang->createIcons['testcase']    = 'sitemap';
$lang->createIcons['doc']         = 'doc';
$lang->createIcons['execution']   = 'run';
$lang->createIcons['project']     = 'project';
$lang->createIcons['product']     = 'product';
$lang->createIcons['program']     = 'program';
$lang->createIcons['kanbanspace'] = 'cube';
$lang->createIcons['kanban']      = 'kanban';


$lang->noMenuModule = array('report', 'my', 'todo', 'effort', 'program', 'product', 'execution', 'task', 'build', 'productplan', 'project', 'projectrelease', 'projectstory', 'story', 'branch', 'release', 'attend', 'leave', 'makeup', 'overtime', 'lieu', 'custom', 'admin', 'mail', 'extension', 'dev', 'backup', 'action', 'cron', 'pssp', 'sms', 'message', 'webhook', 'search', 'score', 'stage', 'entry', 'jenkins', 'gitlab');

if(isset($_SESSION['tutorialMode']) and $_SESSION['tutorialMode'] and !defined('TUTORIAL')) define('TUTORIAL', true);
